import"./outputWidgets.a4629ff8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="f96fa466-17b5-4451-aa5d-40df79a297fb",e._sentryDebugIdIdentifier="sentry-dbid-f96fa466-17b5-4451-aa5d-40df79a297fb")}catch{}})();function s(e){return e.charAt(0).toUpperCase()+e.slice(1)}function d(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{s as c,d as n};
//# sourceMappingURL=string.0031a572.js.map
