import{R as t}from"./Title.cf2a531e.js";import{E as n}from"./outputWidgets.a4629ff8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="755e2a40-9d4c-4c89-9f1b-38cf3b0a9fff",e._sentryDebugIdIdentifier="sentry-dbid-755e2a40-9d4c-4c89-9f1b-38cf3b0a9fff")}catch{}})();const s=n(t);export{s as A};
//# sourceMappingURL=index.46db6cb2.js.map
