import{d as b,ey as g,ez as v,r as _,b as r,c as s,w as a,u as e,f as n,ev as m}from"./outputWidgets.a4629ff8.js";import{S as h,L as w}from"./SmartConsole.c59a847e.js";import{a as x}from"./asyncComputed.fb8b9ba6.js";import{H as B}from"./hooks.ce0d720c.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.f9b0c6e4.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.2c6a5963.js";import{B as I}from"./BaseLayout.4a3e21df.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.47310bca.js";import{_ as $}from"./Debugger.vue_vue_type_script_setup_true_lang.cf40fd84.js";import{c as D}from"./index.dc4c5f56.js";import{A as k,T as R}from"./TabPane.2e2e32c9.js";import"./forms.e81bb060.js";import"./activeRecord.a2b7d343.js";import"./pubsub.25dc8c41.js";import"./dashes.cd571f84.js";import"./runnerData.83399038.js";import"./jobs.51c1e4e4.js";import"./workspaces.6fdb4cab.js";import"./url.d6a620b9.js";import"./icons.73bff2ab.js";import"./Title.cf2a531e.js";import"./index.46db6cb2.js";import"./uuid.af431a29.js";import"./ant-design.523e8417.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.f2becaea.js";import"./RunButton.vue_vue_type_script_setup_true_lang.804cbbd2.js";import"./index.41532d5b.js";import"./index.56cfba6d.js";import"./CollapsePanel.13377319.js";import"./index.fda4c602.js";import"./index.48817ebe.js";import"./index.0f6dde5f.js";import"./Form.ab59726f.js";import"./Text.eb216708.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},p=new Error().stack;p&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[p]="f26a30d3-3814-44b5-8d0b-d7bfeb3acd09",i._sentryDebugIdIdentifier="sentry-dbid-f26a30d3-3814-44b5-8d0b-d7bfeb3acd09")}catch{}})();const de=b({__name:"HookEditor",setup(i){const p=g(),l=v(),f=_(null),o=_("test");function y(){p.push({name:"hooks"})}const{result:t}=x(()=>B.get(l.params.hookPath)),c=w.create();return(A,d)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[n(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:a(()=>[n(e(k),{key:"test",tab:"Test"}),n(e(k),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[n($),n(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):m("",!0)]),_:1},8,["title"])):m("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:f,hook:e(t),"log-service":e(c)},null,8,["hook","log-service"])):m("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):m("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(c),onRestart:(u=f.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):m("",!0)]}),_:1}))}});export{de as default};
//# sourceMappingURL=HookEditor.85abe372.js.map
