import{cC as r}from"./outputWidgets.a4629ff8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="76829129-ae72-44ef-9841-778cedb26d0d",e._sentryDebugIdIdentifier="sentry-dbid-76829129-ae72-44ef-9841-778cedb26d0d")}catch{}})();const t=(e,d)=>{r.error({message:e,description:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.7fcc01cd.js.map
