import{V as i}from"./outputWidgets.a4629ff8.js";import{c,d}from"./index.bb418074.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="47ae03ea-23a6-44f6-857f-7aab92b49853",e._sentryDebugIdIdentifier="sentry-dbid-47ae03ea-23a6-44f6-857f-7aab92b49853")}catch{}})();const{DatePicker:n,WeekPicker:a,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:t,RangePicker:o}=c(d),y=i(n,{WeekPicker:a,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:t,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(a.name,a),e.component(t.name,t),e)});export{y as D,r as M,t as Q,o as R,a as W};
//# sourceMappingURL=dayjs.aae569cd.js.map
