import{B as y,e as u,a as n,c as d}from"./Title.cf2a531e.js";import{V as s,ac as h,f as T,Q as _}from"./outputWidgets.a4629ff8.js";import{a as c,A as m}from"./Text.eb216708.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="fc847a99-d701-49a3-8fb5-8e482ebe5552",e._sentryDebugIdIdentifier="sentry-dbid-fc847a99-d701-49a3-8fb5-8e482ebe5552")}catch{}})();var P=globalThis&&globalThis.__rest||function(e,o){var a={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(a[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(a[t[r]]=e[t[r]]);return a};const w=()=>_(s(s({},u()),{ellipsis:{type:Boolean,default:void 0}}),["component"]),l=(e,o)=>{let{slots:a,attrs:t}=o;const r=s(s({},e),t),{ellipsis:b,rel:i}=r,p=P(r,["ellipsis","rel"]);h();const f=s(s({},p),{rel:i===void 0&&p.target==="_blank"?"noopener noreferrer":i,ellipsis:!!b,component:"a"});return delete f.navigate,T(y,f,a)};l.displayName="ATypographyLink";l.inheritAttrs=!1;l.props=w();const g=l;n.Text=c;n.Title=d;n.Paragraph=m;n.Link=g;n.Base=y;n.install=function(e){return e.component(n.name,n),e.component(n.Text.displayName,c),e.component(n.Title.displayName,d),e.component(n.Paragraph.displayName,m),e.component(n.Link.displayName,g),e};export{g as L};
//# sourceMappingURL=index.874565bb.js.map
