import{d as g,ey as v,ez as k,r as _,b as r,c as s,w as a,u as e,f as n,ev as m}from"./outputWidgets.a4629ff8.js";import{S as j,L as w}from"./SmartConsole.c59a847e.js";import{a as x}from"./asyncComputed.fb8b9ba6.js";import{J as I}from"./jobs.51c1e4e4.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.f9b0c6e4.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.2c6a5963.js";import{B as S}from"./BaseLayout.4a3e21df.js";import{_ as T,a as $}from"./JobSettings.vue_vue_type_script_setup_true_lang.36681d27.js";import{_ as D}from"./Debugger.vue_vue_type_script_setup_true_lang.cf40fd84.js";import{c as R}from"./index.dc4c5f56.js";import{A as b,T as A}from"./TabPane.2e2e32c9.js";import"./forms.e81bb060.js";import"./activeRecord.a2b7d343.js";import"./pubsub.25dc8c41.js";import"./dashes.cd571f84.js";import"./runnerData.83399038.js";import"./hooks.ce0d720c.js";import"./workspaces.6fdb4cab.js";import"./url.d6a620b9.js";import"./icons.73bff2ab.js";import"./Title.cf2a531e.js";import"./index.46db6cb2.js";import"./uuid.af431a29.js";import"./ant-design.523e8417.js";import"./RunButton.vue_vue_type_script_setup_true_lang.804cbbd2.js";import"./index.bb418074.js";import"./index.0f6dde5f.js";import"./dayjs.b16ac109.js";import"./Form.ab59726f.js";import"./Text.eb216708.js";import"./index.fda4c602.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},p=new Error().stack;p&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[p]="063d7945-3051-464e-8633-398474187737",i._sentryDebugIdIdentifier="sentry-dbid-063d7945-3051-464e-8633-398474187737")}catch{}})();const le=g({__name:"JobEditor",setup(i){const p=v(),l=k(),c=_(null),o=_("test");function y(){p.push({name:"jobs"})}const{result:t}=x(()=>I.get(l.params.jobId)),f=w.create();return(J,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(R),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[n(e(A),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:a(()=>[n(e(b),{key:"test",tab:"Test"}),n(e(b),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[n(D),n(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):m("",!0)]),_:1},8,["title"])):m("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:c,job:e(t),"log-service":e(f)},null,8,["job","log-service"])):m("",!0),e(t)&&o.value==="settings"?(r(),s($,{key:1,job:e(t)},null,8,["job"])):m("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(j,{key:0,runtime:"forms","log-service":e(f),onRestart:(u=c.value)==null?void 0:u.test},null,8,["log-service","onRestart"])):m("",!0)]}),_:1}))}});export{le as default};
//# sourceMappingURL=JobEditor.847faff6.js.map
