import"./outputWidgets.a4629ff8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a2628518-53a5-47e6-8e83-4508470b6ee0",e._sentryDebugIdIdentifier="sentry-dbid-a2628518-53a5-47e6-8e83-4508470b6ee0")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.d6a620b9.js.map
