import{d as y,ey as B,ez as C,r as D,H as L,b as t,et as s,bf as f,eA as h,e as _,eB as b,ex as g,f as o,I as v,ev as l,c as k,w as n,u,v as w,eC as $,eD as T,a as A,c0 as N,aI as O}from"./outputWidgets.a4629ff8.js";import{f as V,h as j,j as E,d as H,c as R,m as z,p as F,w as P}from"./icons.73bff2ab.js";import{T as W}from"./Tooltip.7a72d4e4.js";import{_ as q}from"./logo.084e5d7c.js";import{L as J}from"./LoginBlock.09e6653c.js";import{_ as U}from"./DocsButton.vue_vue_type_script_setup_true_lang.2c6a5963.js";import{B as G}from"./BaseLayout.4a3e21df.js";import{c as K}from"./index.dc4c5f56.js";import"./workspaces.6fdb4cab.js";import"./activeRecord.a2b7d343.js";import"./pubsub.25dc8c41.js";import"./url.d6a620b9.js";import"./popupNotifcation.7fcc01cd.js";import"./asyncComputed.fb8b9ba6.js";import"./Text.eb216708.js";import"./Title.cf2a531e.js";import"./index.874565bb.js";import"./index.2517f8f8.js";import"./Form.ab59726f.js";import"./index.fda4c602.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="51474ab8-55c8-45fe-a91b-7f55c6481dbd",a._sentryDebugIdIdentifier="sentry-dbid-51474ab8-55c8-45fe-a91b-7f55c6481dbd")}catch{}})();const M={class:"sidebar"},Q={class:"section-name"},X=["onClick"],Y={class:"item-name"},Z={key:0,class:"tag soon"},ee={key:1,class:"tag beta"},ae={key:2,class:"tag cloud"},te=y({__name:"Sidebar",setup(a){var m;const r=B(),p=C(),c=D((m=p.name)!=null?m:"forms"),I=L(()=>[{name:"Runtime",items:[{name:"Forms",icon:V,path:"forms"},{name:"Hooks",icon:j,path:"hooks"},{name:"Jobs",icon:E,path:"jobs",cloud:!0},{name:"Dashes",icon:H,path:"dashes",beta:!0}]},{name:"Settings",items:[{name:"Style",icon:R,path:"style"},{name:"Sidebar",icon:z,path:"sidebar"},{name:"Packages",icon:F,path:"requirements"}]}]),S=i=>{i.unavailable||(r.push(i.path),c.value=i.path)};return(i,_e)=>(t(),s("div",M,[(t(!0),s(f,null,h(I.value,d=>(t(),s("div",{key:d.name,class:"section"},[_("span",Q,b(d.name),1),(t(!0),s(f,null,h(d.items,e=>(t(),s("div",{key:e.name,role:"button",class:g(["item",{active:c.value===e.path,disabled:e.unavailable||d.cloud}]),tabindex:"0",onClick:pe=>S(e)},[o(v,{class:g(["icon",{disabled:e.unavailable,active:c.value===e.path}]),path:e.icon,width:"20",height:"20"},null,8,["class","path"]),_("span",Y,b(e.name),1),e.unavailable?(t(),s("span",Z,"SOON")):l("",!0),e.beta?(t(),s("span",ee,"BETA")):l("",!0),e.cloud?(t(),s("span",ae,"CLOUD")):l("",!0),e.warning?(t(),k(W,{key:3,class:"warning",text:e.warning,fixed:!0,top:18,left:18},{default:n(()=>[o(v,{path:u(P),fill:"#D35249",width:"20",height:"20"},null,8,["path"])]),_:2},1032,["text"])):l("",!0)],10,X))),128))]))),128))]))}});const se=w(te,[["__scopeId","data-v-a17c56d8"]]);const oe={},x=a=>($("data-v-81cd596e"),a=a(),T(),a),ne={class:"logo"},re=x(()=>_("img",{src:q,alt:"Abstra cloud logo"},null,-1)),ce=x(()=>_("span",null," Abstra ",-1)),ie=[re,ce];function de(a,r){return t(),s("div",ne,ie)}const le=w(oe,[["render",de],["__scopeId","data-v-81cd596e"]]),Ne=y({__name:"Workspace",setup(a){return(r,p)=>{const c=A("router-view");return t(),k(G,null,{navbar:n(()=>[o(u(K),{style:{padding:"5px 10px"}},{title:n(()=>[o(le)]),extra:n(()=>[o(u(N),{type:"primary",href:"/_editor/workflow"},{default:n(()=>[O("Workflow editor")]),_:1}),o(U),o(J)]),_:1})]),sidebar:n(()=>[o(se,{class:"sidebar"})]),content:n(()=>[o(c)]),_:1})}}});export{Ne as default};
//# sourceMappingURL=Workspace.64e4786a.js.map
