import{v as t,b as s,et as o}from"./outputWidgets.a4629ff8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="ba83e124-0f29-48cc-9704-8b49be0f42c5",e._sentryDebugIdIdentifier="sentry-dbid-ba83e124-0f29-48cc-9704-8b49be0f42c5")}catch{}})();const r={},c={class:"organization-settings"};function i(e,n){return s(),o("div",c,"Organization settings")}const f=t(r,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.f76f685d.js.map
