import{x as a}from"./icons.73bff2ab.js";import{d as r,a as c,b as i,et as d,f as _,u as b,aI as f,v as l}from"./outputWidgets.a4629ff8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="cb1b6886-6b95-4db2-b6ee-a088f240600f",e._sentryDebugIdIdentifier="sentry-dbid-cb1b6886-6b95-4db2-b6ee-a088f240600f")}catch{}})();const u=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:b(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),f(" Editor ")])}}});const v=l(u,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.c75d8af0.js.map
