import{V as t,f as c,Q as d,ac as y}from"./outputWidgets.a4629ff8.js";import{B as i,e as f}from"./Title.cf2a531e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ed9cdfce-f1e6-4d9e-98c7-a892e7a50cfa",e._sentryDebugIdIdentifier="sentry-dbid-ed9cdfce-f1e6-4d9e-98c7-a892e7a50cfa")}catch{}})();const g=()=>d(f(),["component"]),r=(e,a)=>{let{slots:o,attrs:p}=a;const s=t(t(t({},e),{component:"div"}),p);return c(i,s,o)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=g();const m=r,h=()=>t(t({},d(f(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),n=(e,a)=>{let{slots:o,attrs:p}=a;const{ellipsis:s}=e;y();const l=t(t(t({},e),{ellipsis:s&&typeof s=="object"?d(s,["expandable","rows"]):s,component:"span"}),p);return c(i,l,o)};n.displayName="ATypographyText";n.inheritAttrs=!1;n.props=h();const x=n;export{m as A,x as a};
//# sourceMappingURL=Text.eb216708.js.map
