import"./outputWidgets.a4629ff8.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="6c43caa7-1613-4f91-9411-e46546fcea8a",x._sentryDebugIdIdentifier="sentry-dbid-6c43caa7-1613-4f91-9411-e46546fcea8a")}catch{}})();const r=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)}),a=()=>Math.random().toString(36).slice(2);export{a as r,r as u};
//# sourceMappingURL=uuid.af431a29.js.map
