import{d as u,ez as b,H as m,a as g,b as f,c as v,w as i,f as s}from"./outputWidgets.a4629ff8.js";import{B as _}from"./BaseLayout.4a3e21df.js";import{a as h}from"./asyncComputed.fb8b9ba6.js";import{P as y}from"./project.b861b2fe.js";import"./router.ab2ac3ba.js";import{O as z}from"./organization.6571a8a9.js";import"./columns.464a3bb5.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.d4c1eb85.js";import{S as I}from"./Sidebar.aa249497.js";import{n as w,J as k,K as B,L as P,M as $,N as C,O as M,G as x,H as D,I as L}from"./icons.73bff2ab.js";import"./gateway.68939de7.js";import"./activeRecord.a2b7d343.js";import"./pubsub.25dc8c41.js";import"./Title.cf2a531e.js";import"./index.339c7421.js";import"./index.f4ac7424.js";import"./logo.084e5d7c.js";import"./Text.eb216708.js";import"./index.fda4c602.js";import"./index.dc4c5f56.js";import"./Tooltip.7a72d4e4.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="8d2ecba7-34e3-4f1c-9f48-dc8d493175ef",o._sentryDebugIdIdentifier="sentry-dbid-8d2ecba7-34e3-4f1c-9f48-dc8d493175ef")}catch{}})();const ea=u({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=h(()=>y.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),d=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:D,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=g("router-view");return f(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:d.value},null,8,["sections"])]),_:1})}}});export{ea as default};
//# sourceMappingURL=Project.11f50f38.js.map
